@@ -12,9 +12,9 @@ from ninja.types import TCallable
 from ninja_extra import NinjaExtraAPI
 
 from easy.controller.auto_api import create_admin_controller
-from easy.domain.serializers import django_serializer
+from easy.domain.orm import django_serializer
 from easy.renderer.json import EasyJSONRenderer
-from easy.response import BaseApiResponse
+from easy.response import BaseAPIResponse
 
 logger = logging.getLogger(__name__)
 
@@ -29,9 +29,9 @@ class EasyAPI(NinjaExtraAPI):
             If True, will be encapsulated in BaseAPIResponse
     -renderer, default to EasyJSONRenderer
     -Auto generate AdminAPIs, it will read the following settings:
-        AUTO_ADMIN_ENABLED_ALL_APPS
-        AUTO_ADMIN_EXCLUDE_APPS
-        AUTO_ADMIN_INCLUDE_APPS
+        CRUD_API_ENABLED_ALL_APPS
+        CRUD_API_EXCLUDE_APPS
+        CRUD_API_INCLUDE_APPS
     """
 
     def __init__(
@@ -75,17 +75,17 @@ class EasyAPI(NinjaExtraAPI):
     def auto_create_admin_controllers(self, version: str = None) -> None:
         for app_module in self.get_installed_apps():
             # If not all
-            if not settings.AUTO_ADMIN_ENABLED_ALL_APPS:  # type:ignore
+            if not settings.CRUD_API_ENABLED_ALL_APPS:  # type:ignore
                 # Only generate for this included apps
-                if settings.AUTO_ADMIN_INCLUDE_APPS is not None:  # type:ignore
+                if settings.CRUD_API_INCLUDE_APPS is not None:  # type:ignore
                     if (
                         app_module.name
-                        not in settings.AUTO_ADMIN_INCLUDE_APPS  # type:ignore
+                        not in settings.CRUD_API_INCLUDE_APPS  # type:ignore
                     ):
                         continue
 
             # Exclude list
-            if app_module.name in settings.AUTO_ADMIN_EXCLUDE_APPS:  # type:ignore
+            if app_module.name in settings.CRUD_API_EXCLUDE_APPS:  # type:ignore
                 continue
 
             try:
@@ -126,14 +126,14 @@ class EasyAPI(NinjaExtraAPI):
                 data = django_serializer.serialize_data(data)
             except Exception as e:  # pragma: no cover
                 logger.error(f"Creat Response Error - {e}", exc_info=True)
-                return BaseApiResponse(str(e), code=500)
+                return BaseAPIResponse(str(e), code=500)
 
         if self.easy_output:
             if temporal_response:
                 status = temporal_response.status_code
             assert status
 
-            _temp = BaseApiResponse(
+            _temp = BaseAPIResponse(
                 data, status=status, content_type=self.get_content_type()
             )
 
@@ -154,6 +154,6 @@ class EasyAPI(NinjaExtraAPI):
 
     def create_temporal_response(self, request: HttpRequest) -> HttpResponse:
         if self.easy_output:
-            return BaseApiResponse("", content_type=self.get_content_type())
+            return BaseAPIResponse("", content_type=self.get_content_type())
         else:
             return super().create_temporal_response(request)
